# Mobile Robot Environments

Mobile environments are currently limited to simple demos for wheeled and aerial robots. Future plans include integrating spacecrafts in orbital scenarios and defining a set of tasks for each robot type.

- [Wheeled Robot Environments](./mobile_wheeled.md)
- [Aerial Robot Environments](./mobile_aerial.md)
